@@ -1039,8 +1039,7 @@
              (clear! ,clear!)
              (edge ,edge)
              (source ,source)
-             (target ,target)
-             (edge-at ,edge-at))
+             (target ,target))
          ,@rest))))
 (define rgraph-doc-fill-graph! #t)
 (define-macro
